import request from '@/utils/request'
import Qs from 'qs'

// 查询字典数据列表
export function listData(query) {
  return request({
    url: '/system/dict/data/list',
    method: 'get',
    params: query
  })
}

// 查询字典数据详细
export function getData(dictCode) {
  return request({
    url: '/system/dict/data/detail/' + dictCode,
    method: 'get'
  })
}

// 根据字典类型查询字典数据信息
export function getDicts(dictType) {
  return request({
    url: '/system/dict/data/type/' + dictType,
    method: 'get'
  })
}

// 查询字典类型
export function checkDictLabelUnique(dictLabel) {
  return request({
    url: '/system/dict/data/checkDictLabelUnique?dictLabel=' + dictLabel,
    method: 'get'
  })
}

// 新增字典数据
export function addData(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/dict/data/add',
    method: 'post',
    data: data,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}

// 修改字典数据
export function updateData(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/dict/data/update/' + businessId,
    method: 'put',
    data: data,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}

// 删除字典数据
export function delData(dictCode) {
  return request({
    url: '/system/dict/data/deleteLogical/' + dictCode,
    method: 'delete',
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}

// 导出字典数据
export function exportData(query) {
  return request({
    url: '/system/dict/data/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}
